Index: kernel/genarch/src/multiboot/multiboot.c
===================================================================
--- kernel/genarch/src/multiboot/multiboot.c	(revision 8be323084b791c62927f9cbb14696265246370dd)
+++ kernel/genarch/src/multiboot/multiboot.c	(revision 4bb4cf88f506ddc6012f655a28835fe8872e9f71)
@@ -55,8 +55,8 @@
 	/*
 	 * Find last occurence of '/' before 'end'. If found, place start at
 	 * next character. Otherwise, place start at beginning of buffer.
 	 */
 	const char *cp = end;
-	const char *start = buf;
+	const char *start = cmd_line;
 
 	while (cp != start) {
@@ -55,8 +55,8 @@
 	/*
 	 * Find last occurence of '/' before 'end'. If found, place start at
-	 * next character. Otherwise, place start at beginning of buffer.
+	 * next character. Otherwise, place start at beginning of command line.
 	 */
 	const char *cp = end;
